Temporary DID Rest API — Rucio 1.2 documentation

# Temporary DID Rest API

Overview

Resource | Operation | Description
--- | --- | ---
BulkDIDS | POST /temporary_dids/ | Bulk add temporary dids.

Details

`POST` `/temporary_dids/`

  Bulk add temporary data identifiers.

  Request JSON Object:
  | dids (list) – A list of dids.
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.